/*
 * Created on 12.04.2004
 * $Id: AdbClient.java,v 1.6 2005/01/05 18:23:05 Heiko Exp $
 */
package de.bsd.adb.client;

import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStreamReader;
import java.io.UnsupportedEncodingException;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.Properties;
import javax.naming.InitialContext;
import javax.security.auth.callback.CallbackHandler;
import javax.security.auth.login.LoginContext;
import javax.security.auth.login.LoginException;

import de.bsd.adb.beans.AddrBean;
import de.bsd.adb.ejb.Facade;
import de.bsd.adb.ejb.FacadeHome;
import de.bsd.adb.ejb.WSClient;
import de.bsd.adb.ejb.WSClientHome;

/**
 * @author hwr@pilhuhn.de
 * @version $Revision: 1.6 $
 */
public class AdbClient {
	

	public static void main(String[] args) {
		
		if (args.length<1 || (args.length==1) && args[0].equals("-h")) {
			usage();
			return;
		}
		AdbClient ac = new AdbClient();		
		ac. run(args);
	}

	/**
	 * Give a usage description
	 */
	private static void usage() {
		System.out.println("Benutzung:");
		System.out.println(" AdbClient suche Name [Vorname]");
		System.out.println(" AdbClient suchews Name [Vorname]");
		System.out.println(" AdbClient add");
	}

	/**
	 * Do the work
	 * @param args command line arguments
	 */
	private  void run(String[] args) {
		FacadeHome fh;
		Facade fa;
		
		
		Properties p = new Properties();
		// Knnten auch aus einer Datei jndi.properties geladen werden
		p.put("java.naming.factory.initial",
			"org.jnp.interfaces.NamingContextFactory");
		p.put("java.naming.factory.url.pkgs",
			"org.jboss.naming:org.jnp.interfaces");
		p.put("java.naming.provider.url","jnp://localhost:1099");
		
		
		try {
			InitialContext ic = new InitialContext(p);
			Object o = ic.lookup(FacadeHome.JNDI_NAME);
			fh = (FacadeHome) o;
		
			if (args[0].equals("suche")) {
				AddrBean[] a;
				if (args.length < 2 ) {
					usage();
					return;
				}
				
				fa=fh.create();
				if (args.length==2)
					a = fa.suche(args[1],null);
				else
					a = fa.suche(args[1],args[2]);
					
				fa.remove();
					
				if (a==null) {
					System.err.println("Oops. Suche nicht erfolgreich.");
					return;
				}
				
				System.out.println("Ergebnis: " + a.length + " Eintrge\n"); 
				
				for (int i=0; i<a.length; i++) {			
					addresseAusgeben(a[i]);
				}
			}
			else if ("suchews".equals(args[0])) {
				String[] a;
				o = ic.lookup(WSClientHome.JNDI_NAME);
				WSClientHome wh = (WSClientHome)o;
				WSClient wc = wh.create();

				if (args.length < 2 ) {
					usage();
					return;
				}

				if (args.length==2)
					a = wc.listEmails(args[1],null);
				else
					a = wc.listEmails(args[1],args[2]);
				
				if (a==null) {
					System.err.println("Suche nicht erfolgreich");
					return;
				}
				System.out.println("Ergebnis: " + a.length + " Eintrge\n"); 
				
				for (int i=0; i<a.length; i++) {			
					System.out.println(a[i]);
				}
				
				
			}
			else if (args[0].equals("add")){
				AddrBean aBean;
				doLogin();
				fa=fh.create();
				System.out.println("Facade created");
				aBean = addresseEinlesen();				
			
				fa=fh.create();
				fa.add(aBean); 
				fa.remove();
				
			}			
			else {
				usage();
			}
		}
		catch (Exception e) {
			e.printStackTrace();			
		}
	}

	/**
	 * Read an address from stdin
	 * @return the adress read
	 * @throws UnsupportedEncodingException
	 * @throws IOException
	 */
	private AddrBean addresseEinlesen()
		throws UnsupportedEncodingException, IOException {
		char b[] = new char[30];
		AddrBean a = new AddrBean();
		InputStreamReader isr = new InputStreamReader(System.in,"ISO-8859-1");
		BufferedReader br = new BufferedReader(isr);
		
		System.out.print("Name: ");				
		a.setName(br.readLine());
		System.out.print("Vorname: ");	
		a.setVorname(br.readLine());
		System.out.print("PLZ: ");	
		a.setPlz(br.readLine());
		System.out.print("Ort: ");	
		a.setOrt(br.readLine());
		System.out.print("Strasse: ");	
		a.setStrasse(br.readLine());
		System.out.print("Tel: ");	
		a.setTel(br.readLine());
		System.out.print("Email: ");	
		String email = br.readLine();
		ArrayList emails = new ArrayList();
		emails.add(email);
		a.setEmails(emails);
		return a;
	}

	/**
	 * Print an addres to stdout
	 * @param a
	 */
	private void addresseAusgeben(AddrBean a) {
		System.out.println(a.getName() + ", " + a.getVorname());
		System.out.println(a.getStrasse());
		System.out.println(a.getPlz() + " " + a.getOrt());
		System.out.print(a.getTel() + " , " );
		if (a.getEmails()!=null) {
			Iterator it = a.getEmails().iterator();
			while (it.hasNext()) {
				System.out.print((String)it.next());
				if (it.hasNext())
					System.out.print(", ");
			}
		}
		System.out.println();
	}
	
	private void doLogin() {

		String user=null;
		String pass=null;
				
		try {
			InputStreamReader isr = new InputStreamReader(System.in,"ISO-8859-1");
			BufferedReader br = new BufferedReader(isr);
			
			System.out.print("Login: ");				
			user=br.readLine();
			System.out.print("Passwort: ");
			pass=br.readLine();
		} catch (UnsupportedEncodingException e1) {
			// ...
			e1.printStackTrace();
		} catch (IOException e1) {
			// ...
			e1.printStackTrace();
		}
		CallbackHandler cbh = new LoginCallbackHandler(user,pass.toCharArray());
		
		try {
			LoginContext lc = new LoginContext("adb",cbh);
			lc.login();
		} catch (LoginException e) {
			System.err.println("Login failed: " + e.getMessage());
		}
	}
}