package de.bsd.adb.ejb;

import java.util.Collection;

import javax.ejb.CreateException;
import javax.ejb.EntityBean;

import de.bsd.adb.beans.AddrBean;


/**
 * @ejb.bean name="Address"
 * 	type="CMP"
 * 	cmp-version="2.x"
 * 	view-type="local"
 * 	local-jndi-name="adb/Address"
 * 	primkey-field = "primkey"
 *	
 * @ejb.security-identity use-caller-identity = "true"
 * 
 * @ejb.persistence table-name = "adb_Address"
 * @jboss.persistence 
 * 	create-table = "${create.table}"
 * 	remove-table = "${remove.table}"
 * 	pk-constraint = "false"
 * 
 * @ejb.finder query = "SELECT Object(o) FROM Address 
      AS o WHERE o.name=?1 AND o.vorname=?2" 
 * 	signature = "java.util.Collection 
              findByNameAndVorname(java.lang.String name, java.lang.String vorname)"
      unchecked="true"
 * 
 * @ejb.finder query = "SELECT Object(o) FROM Address AS o WHERE o.name=?1"
 * 	signature = "java.util.Collection findByName(java.lang.String name)"
 * 	unchecked = "true"
 * 
 * @jboss.query signature = "java.util.Collection findByName(java.lang.String name)"
 * 	query = "SELECT Object(o) FROM Address AS o WHERE o.name LIKE ?1 ORDER BY o.vorname"
 *
 * @ejb.permission unchecked = "true"
 * 
 * @jboss.entity-command name = "hsqldb-fetch-key"
 */
public abstract class AddressEntityBean implements EntityBean {	

	/**
	 * @ejb.create-method
	 * @Xejb.permission role-name = "ADBadmin"
	 * @param a an address to be stored
	 * @throws CreateException
	 */
	public Integer ejbCreate(AddrBean a, Collection emails) throws CreateException {
		if (a==null)
			throw new CreateException();
		
		setName(a.getName());
		setVorname(a.getVorname());
		setOrt(a.getOrt());
		setPlz(a.getPlz());
		setStrasse(a.getStrasse());
		
		setTel(a.getTel());
		
		return null;
	}
	
	public void ejbPostCreate(AddrBean a, Collection emails) {
		if (emails!=null)
			setEmails(emails);
	}
	
	/** 
	 * @ejb.interface-method
	 * @ejb.persistence 
	 * @jboss.persistence auto-increment = "true"
	 */
	public abstract Integer getPrimkey();

	/**
	 * @ejb.interface-method 
	 * @ejb.persistence  
	 * @return
	 */
	public abstract String getName();
	
	/** @ejb.interface-method */
	public abstract void setName(String name);	

	/**
	 * @ejb.interface-method 
	 * @ejb.persistence 
	 * @return
	 */
	public abstract String getVorname();
	
	/** @ejb.interface-method */
	public abstract void setVorname(String vorname);	

	/**
	 * @ejb.interface-method 
	 * @ejb.persistence 
	 * @return
	 */
	public abstract String getStrasse();
	
	/** @ejb.interface-method */
	public abstract void setStrasse(String strasse);	

	/**
	 * @ejb.interface-method 
	 * @ejb.persistence 
	 * @jboss.jdbc-type type="VARCHAR"
	 * @jboss.sql-type type="VARCHAR(8)"
	 * @return
	 */
	public abstract String getPlz();
	
	/** @ejb.interface-method */
	public abstract void setPlz(String plz);	

	/**
	 * @ejb.interface-method 
	 * @ejb.persistence 
	 * @return
	 */
	public abstract String getOrt();
	
	/** @ejb.interface-method */
	public abstract void setOrt(String ort);	

	/**
	 * @ejb.interface-method 
	 * @ejb.persistence 
	 * @return
	 */
	public abstract String getTel();
	
	/** @ejb.interface-method */
	public abstract void setTel(String tel);	

	
	/**
	 * @ejb.relation name = "EMails"
	 * 	role-name = "Address-has-Emails"
	 * 	target-ejb = "Email"
	 * 	target-role-name = "Emails-of-Address" 	
	 *    target-cascade-delete = "true"
	 * 
	 * @jboss.target-relation fk-column = "address_fk"
	 * 	related-pk-field = "primkey"
	 * @jboss.relation-mapping style="foreign-key"
	 * @jboss.relation-read-ahead strategy = "on-load"
	 * 
	 * @ejb.interface-method 
	 */
	public abstract Collection getEmails();
	
	/** @ejb.interface-method */
	public abstract void setEmails(Collection emails);
}
