/*
 * Created on 04.04.2004
 * $Id: FacadeSessionBean.java,v 1.7 2005/01/05 18:23:04 Heiko Exp $
 */
package de.bsd.adb.ejb;

import java.util.ArrayList;
import java.util.Collection;
import java.util.Iterator;

import javax.ejb.CreateException;
import javax.ejb.EJBException;
import javax.ejb.FinderException;
import javax.ejb.SessionBean;
import javax.naming.InitialContext;
import javax.naming.NamingException;

import de.bsd.adb.beans.AddrBean;

/**
 * @ejb.bean name = "Facade"
 * 	type="Stateless"
 * 	view-type = "both"
 * 	jndi-name = "adb/Facade"
 * 	local-jndi-name ="adb/FacadeLocal"
 * 
 * @Xejb.security-identity use-caller-identity = "true"
 * @ejb.security-role-ref role-name = "ADBuser"
 * 	role-link = "ADBadmin"
 * 
 * @jboss.container-configuration name="ADBFacadeContainer"
 * 	
 */
public abstract class FacadeSessionBean implements SessionBean {
	
	private AddressLocalHome alh=null;
	private EmailLocalHome elh = null;
	private WSClientLocal wc = null;
	private WSClientLocalHome wch = null;

	/**
	 * @ejb.create-method 
	 * @ejb.permission unchecked = "true"
	 * @throws CreateException
	 */
	public void ejbCreate() throws CreateException {
		try {
			InitialContext ic = new InitialContext();
			Object o = ic.lookup("adb/Address");
			alh = (AddressLocalHome) o;
			
			o = ic.lookup("adb/Email");
			elh = (EmailLocalHome) o;
			
			o= ic.lookup("adb/WSClientLocal");
			wch = (WSClientLocalHome) o;
			wc = wch.create();
		} 
		catch (NamingException e) {
			throw new CreateException(e.getMessage());
		}		
	}

	/**
	 * @ejb.interface-method
	 * @ejb.permission unchecked = "true"
	 * @param name
	 * @param vorname
	 * @return
	 */
	public AddrBean[] suche(String name, String vorname) {
				
		AddrBean[] result=null;
		try {
			Collection co;
			
			if (vorname==null || vorname.equals(""))
				co = alh.findByName(name);
			else
				co = alh.findByNameAndVorname(name,vorname);
			
			int size = co.size();
			if (size>0) {
				result = new AddrBean[size];
			
				Iterator it = co.iterator();
				int i = 0;
				while(it.hasNext()) {
					
					AddressLocal al = (AddressLocal) it.next();
					result[i] = new AddrBean();					
					
					result[i].setName(al.getName());
					result[i].setVorname(al.getVorname());					
					result[i].setPlz(al.getPlz());
					result[i].setOrt(al.getOrt());
					result[i].setStrasse(al.getStrasse());
					result[i].setTel(al.getTel());
					
					if (al.getEmails()!=null) {
						// EMails auslesen
						ArrayList mails = new ArrayList();
						Iterator eit = al.getEmails().iterator();
						while (eit.hasNext()) {
							EmailLocal el = (EmailLocal)eit.next();
							String mail = el.getTheEmail();
							mails.add(mail);
						}
						result[i].setEmails(mails);
					}
					i++;
				}
			}
		} catch (FinderException e) {
			result= null;
		}		
		return result;
	}
	
	/**
	 * @ejb.interface-method 
	 * @ejb.permission role-name = "ADBadmin" 
	 * @param a
	 * @return
	 */
	public AddrBean add(AddrBean a) throws CreateException {
		
		if (a == null)
			throw new CreateException("Keine Adresse bergeben");
		
		AddressLocal al;
		ArrayList emailLocals = null;
		// Emails in a anlegen
		
		if (a.getEmails()!=null) {
			emailLocals = new ArrayList();
			Iterator it = a.getEmails().iterator();
			while (it.hasNext()) {
				String em = (String)it.next();
				EmailLocal el = elh.create(em);
				emailLocals.add(el);
			}
		}
		al = alh.create(a,emailLocals);			
		System.out.println("Add successful");
		return a;
	}
	
	
	/**
	 * @ejb.interface-method 
	 * @ejb.permission unchecked = "true"
	 */
	public void ejbRemove() throws EJBException {
		 // nothing to do
	}

}
